Crate nibblecode

Crate nibblecode 

Modules

aligned_alloc
boxed
An archived version of Box.
list
option
An archived version of Option.
primitive
Definitions of archived primitives and type aliases based on enabled features.
result
An archived version of Result.
string
An archived string representation that supports inlining short strings.
tuple
Archived versions of tuple types.
util

Enums

SerializeError
VerifyError

Traits

Serialize
A type that can be serialized and accessed in it’s serialized form (as Self::Archived)

Functions

access
Access a byte slice.
access_mut
Mutably access a byte slice.
access_ptr
Verify this buffer and return a pointer to the archived data.
access_ptr_unchecked
Return a pointer to the archived data without verifying it.
access_unchecked
Access a byte slice.
access_unchecked_mut
Mutably access a byte slice.
to_bytes
Serialize a value to bytes.
to_bytes_in
Serialize a value and write the bytes to the given buffer, returning th number of bytes written.
to_bytes_in_unchecked
Serialize a value and write the bytes to the given buffer without checking the length or validity.

Derive Macros

Serialize
Derives Serialize for the labeled type.