Modules
- aligned_
alloc - boxed
- An archived version of
Box. - list
- option
- An archived version of
Option. - primitive
- Definitions of archived primitives and type aliases based on enabled features.
- result
- An archived version of
Result. - string
- An archived string representation that supports inlining short strings.
- tuple
- Archived versions of tuple types.
- util
Enums
Traits
- Serialize
- A type that can be serialized and accessed in it’s serialized form (as
Self::Archived)
Functions
- access
- Access a byte slice.
- access_
mut - Mutably access a byte slice.
- access_
ptr - Verify this buffer and return a pointer to the archived data.
- access_
ptr_ ⚠unchecked - Return a pointer to the archived data without verifying it.
- access_
unchecked ⚠ - Access a byte slice.
- access_
unchecked_ ⚠mut - Mutably access a byte slice.
- to_
bytes - Serialize a value to bytes.
- to_
bytes_ in - Serialize a value and write the bytes to the given buffer, returning th number of bytes written.
- to_
bytes_ ⚠in_ unchecked - Serialize a value and write the bytes to the given buffer without checking the length or validity.
Derive Macros
- Serialize
- Derives
Serializefor the labeled type.